==> iam-1.30.0-sources.jar: software/amazon/awscdk/services/iam/UnknownPrincipalProps.java <==
package software.amazon.awscdk.services.iam;

/**
 * Properties for an UnknownPrincipal.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-03-18T17:03:08.388Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.UnknownPrincipalProps")
@software.amazon.jsii.Jsii.Proxy(UnknownPrincipalProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface UnknownPrincipalProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The resource the role proxy is for.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.core.IConstruct getResource();

    /**
     * @return a {@link Builder} of {@link UnknownPrincipalProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link UnknownPrincipalProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private software.amazon.awscdk.core.IConstruct resource;

        /**
         * Sets the value of {@link UnknownPrincipalProps#getResource}
         * @param resource The resource the role proxy is for. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resource(software.amazon.awscdk.core.IConstruct resource) {
            this.resource = resource;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link UnknownPrincipalProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public UnknownPrincipalProps build() {
            return new Jsii$Proxy(resource);
        }
    }

    /**
     * An implementation for {@link UnknownPrincipalProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements UnknownPrincipalProps {
        private final software.amazon.awscdk.core.IConstruct resource;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.resource = this.jsiiGet("resource", software.amazon.awscdk.core.IConstruct.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.core.IConstruct resource) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.resource = java.util.Objects.requireNonNull(resource, "resource is required");
        }

        @Override
        public software.amazon.awscdk.core.IConstruct getResource() {
            return this.resource;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("resource", om.valueToTree(this.getResource()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iam.UnknownPrincipalProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            UnknownPrincipalProps.Jsii$Proxy that = (UnknownPrincipalProps.Jsii$Proxy) o;

            return this.resource.equals(that.resource);
        }

        @Override
        public int hashCode() {
            int result = this.resource.hashCode();
            return result;
        }
    }
}

==> iam-1.32.0-sources.jar: software/amazon/awscdk/services/iam/UnknownPrincipalProps.java <==
package software.amazon.awscdk.services.iam;

/**
 * Properties for an UnknownPrincipal.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.1.0 (build df55f5e)", date = "2020-04-07T12:30:24.047Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iam.$Module.class, fqn = "@aws-cdk/aws-iam.UnknownPrincipalProps")
@software.amazon.jsii.Jsii.Proxy(UnknownPrincipalProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface UnknownPrincipalProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The resource the role proxy is for.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.IConstruct getResource();

    /**
     * @return a {@link Builder} of {@link UnknownPrincipalProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link UnknownPrincipalProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private software.amazon.awscdk.core.IConstruct resource;

        /**
         * Sets the value of {@link UnknownPrincipalProps#getResource}
         * @param resource The resource the role proxy is for. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resource(software.amazon.awscdk.core.IConstruct resource) {
            this.resource = resource;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link UnknownPrincipalProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public UnknownPrincipalProps build() {
            return new Jsii$Proxy(resource);
        }
    }

    /**
     * An implementation for {@link UnknownPrincipalProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements UnknownPrincipalProps {
        private final software.amazon.awscdk.core.IConstruct resource;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.resource = this.jsiiGet("resource", software.amazon.awscdk.core.IConstruct.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.core.IConstruct resource) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.resource = java.util.Objects.requireNonNull(resource, "resource is required");
        }

        @Override
        public software.amazon.awscdk.core.IConstruct getResource() {
            return this.resource;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("resource", om.valueToTree(this.getResource()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iam.UnknownPrincipalProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            UnknownPrincipalProps.Jsii$Proxy that = (UnknownPrincipalProps.Jsii$Proxy) o;

            return this.resource.equals(that.resource);
        }

        @Override
        public int hashCode() {
            int result = this.resource.hashCode();
            return result;
        }
    }
}
